pub struct Compression(/* private fields */);Implementations
Sourceimpl Compression
impl Compression
pub const BITMAP_COMPRESSION: Compression
pub const NO_BITMAP_COMPRESSION_HDR: Compression
Sourceimpl Compression
impl Compression
Sourcepub const fn empty() -> Compression
pub const fn empty() -> Compression
Get a flags value with all bits unset.
Sourcepub const fn all() -> Compression
pub const fn all() -> Compression
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Compression>
pub const fn from_bits(bits: u16) -> Option<Compression>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Compression
pub const fn from_bits_truncate(bits: u16) -> Compression
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Compression
pub const fn from_bits_retain(bits: u16) -> Compression
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Compression>
pub fn from_name(name: &str) -> Option<Compression>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Compression) -> bool
pub const fn intersects(&self, other: Compression) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Compression) -> bool
pub const fn contains(&self, other: Compression) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: Compression)
pub fn insert(&mut self, other: Compression)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: Compression)
pub fn remove(&mut self, other: Compression)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Compression)
pub fn toggle(&mut self, other: Compression)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Compression, value: bool)
pub fn set(&mut self, other: Compression, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Compression) -> Compression
pub const fn intersection(self, other: Compression) -> Compression
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Compression) -> Compression
pub const fn union(self, other: Compression) -> Compression
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Compression) -> Compression
pub const fn difference(self, other: Compression) -> Compression
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Compression) -> Compression
pub const fn symmetric_difference(self, other: Compression) -> Compression
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Compression
pub const fn complement(self) -> Compression
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Compression
impl Compression
Sourcepub const fn iter(&self) -> Iter<Compression>
pub const fn iter(&self) -> Iter<Compression>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Compression>
pub const fn iter_names(&self) -> IterNames<Compression>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.