pub struct CacheFlags(/* private fields */);Implementations
Sourceimpl CacheFlags
impl CacheFlags
pub const PERSISTENT_KEYS_EXPECTED_FLAG: CacheFlags
pub const ALLOW_CACHE_WAITING_LIST_FLAG: CacheFlags
Sourceimpl CacheFlags
impl CacheFlags
Sourcepub const fn empty() -> CacheFlags
pub const fn empty() -> CacheFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> CacheFlags
pub const fn all() -> CacheFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<CacheFlags>
pub const fn from_bits(bits: u16) -> Option<CacheFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> CacheFlags
pub const fn from_bits_truncate(bits: u16) -> CacheFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> CacheFlags
pub const fn from_bits_retain(bits: u16) -> CacheFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<CacheFlags>
pub fn from_name(name: &str) -> Option<CacheFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: CacheFlags) -> bool
pub const fn intersects(&self, other: CacheFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: CacheFlags) -> bool
pub const fn contains(&self, other: CacheFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: CacheFlags)
pub fn insert(&mut self, other: CacheFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: CacheFlags)
pub fn remove(&mut self, other: CacheFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: CacheFlags)
pub fn toggle(&mut self, other: CacheFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: CacheFlags, value: bool)
pub fn set(&mut self, other: CacheFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: CacheFlags) -> CacheFlags
pub const fn intersection(self, other: CacheFlags) -> CacheFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: CacheFlags) -> CacheFlags
pub const fn union(self, other: CacheFlags) -> CacheFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: CacheFlags) -> CacheFlags
pub const fn difference(self, other: CacheFlags) -> CacheFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: CacheFlags) -> CacheFlags
pub const fn symmetric_difference(self, other: CacheFlags) -> CacheFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> CacheFlags
pub const fn complement(self) -> CacheFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl CacheFlags
impl CacheFlags
Sourcepub const fn iter(&self) -> Iter<CacheFlags>
pub const fn iter(&self) -> Iter<CacheFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CacheFlags>
pub const fn iter_names(&self) -> IterNames<CacheFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.