pub struct FileSystemAttributes(/* private fields */);Expand description
See 2.5.1 FileFsAttributeInformation.
Implementations
Sourceimpl FileSystemAttributes
impl FileSystemAttributes
pub const FILE_SUPPORTS_USN_JOURNAL: FileSystemAttributes
pub const FILE_SUPPORTS_OPEN_BY_FILE_ID: FileSystemAttributes
pub const FILE_SUPPORTS_EXTENDED_ATTRIBUTES: FileSystemAttributes
pub const FILE_SUPPORTS_HARD_LINKS: FileSystemAttributes
pub const FILE_SUPPORTS_TRANSACTIONS: FileSystemAttributes
pub const FILE_SEQUENTIAL_WRITE_ONCE: FileSystemAttributes
pub const FILE_READ_ONLY_VOLUME: FileSystemAttributes
pub const FILE_NAMED_STREAMS: FileSystemAttributes
pub const FILE_SUPPORTS_ENCRYPTION: FileSystemAttributes
pub const FILE_SUPPORTS_OBJECT_IDS: FileSystemAttributes
pub const FILE_VOLUME_IS_COMPRESSED: FileSystemAttributes
pub const FILE_SUPPORTS_REMOTE_STORAGE: FileSystemAttributes
pub const FILE_SUPPORTS_REPARSE_POINTS: FileSystemAttributes
pub const FILE_SUPPORTS_SPARSE_FILES: FileSystemAttributes
pub const FILE_VOLUME_QUOTAS: FileSystemAttributes
pub const FILE_FILE_COMPRESSION: FileSystemAttributes
pub const FILE_PERSISTENT_ACLS: FileSystemAttributes
pub const FILE_UNICODE_ON_DISK: FileSystemAttributes
pub const FILE_CASE_PRESERVED_NAMES: FileSystemAttributes
pub const FILE_CASE_SENSITIVE_SEARCH: FileSystemAttributes
pub const FILE_SUPPORT_INTEGRITY_STREAMS: FileSystemAttributes
pub const FILE_SUPPORTS_BLOCK_REFCOUNTING: FileSystemAttributes
pub const FILE_SUPPORTS_SPARSE_VDL: FileSystemAttributes
Sourceimpl FileSystemAttributes
impl FileSystemAttributes
Sourcepub const fn empty() -> FileSystemAttributes
pub const fn empty() -> FileSystemAttributes
Get a flags value with all bits unset.
Sourcepub const fn all() -> FileSystemAttributes
pub const fn all() -> FileSystemAttributes
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<FileSystemAttributes>
pub const fn from_bits(bits: u32) -> Option<FileSystemAttributes>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> FileSystemAttributes
pub const fn from_bits_truncate(bits: u32) -> FileSystemAttributes
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> FileSystemAttributes
pub const fn from_bits_retain(bits: u32) -> FileSystemAttributes
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<FileSystemAttributes>
pub fn from_name(name: &str) -> Option<FileSystemAttributes>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: FileSystemAttributes) -> bool
pub const fn intersects(&self, other: FileSystemAttributes) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: FileSystemAttributes) -> bool
pub const fn contains(&self, other: FileSystemAttributes) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: FileSystemAttributes)
pub fn insert(&mut self, other: FileSystemAttributes)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: FileSystemAttributes)
pub fn remove(&mut self, other: FileSystemAttributes)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: FileSystemAttributes)
pub fn toggle(&mut self, other: FileSystemAttributes)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: FileSystemAttributes, value: bool)
pub fn set(&mut self, other: FileSystemAttributes, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: FileSystemAttributes,
) -> FileSystemAttributes
pub const fn intersection( self, other: FileSystemAttributes, ) -> FileSystemAttributes
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: FileSystemAttributes) -> FileSystemAttributes
pub const fn union(self, other: FileSystemAttributes) -> FileSystemAttributes
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: FileSystemAttributes,
) -> FileSystemAttributes
pub const fn difference( self, other: FileSystemAttributes, ) -> FileSystemAttributes
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: FileSystemAttributes,
) -> FileSystemAttributes
pub const fn symmetric_difference( self, other: FileSystemAttributes, ) -> FileSystemAttributes
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> FileSystemAttributes
pub const fn complement(self) -> FileSystemAttributes
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl FileSystemAttributes
impl FileSystemAttributes
Sourcepub const fn iter(&self) -> Iter<FileSystemAttributes>
pub const fn iter(&self) -> Iter<FileSystemAttributes>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FileSystemAttributes>
pub const fn iter_names(&self) -> IterNames<FileSystemAttributes>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.