pub struct SimplexStream { /* private fields */ }Expand description
A unidirectional pipe to read and write bytes in memory.
It can be constructed by simplex function which will create a pair of
reader and writer or by calling SimplexStream::new_unsplit that will
create a handle for both reading and writing.
Example
let (mut receiver, mut sender) = tokio::io::simplex(64);
sender.write_all(b"ping").await?;
let mut buf = [0u8; 4];
receiver.read_exact(&mut buf).await?;
assert_eq!(&buf, b"ping");Implementations
Sourceimpl SimplexStream
impl SimplexStream
Sourcepub fn new_unsplit(max_buf_size: usize) -> SimplexStream
pub fn new_unsplit(max_buf_size: usize) -> SimplexStream
Creates unidirectional buffer that acts like in memory pipe. To create split
version with separate reader and writer you can use simplex function.
The max_buf_size argument is the maximum amount of bytes that can be
written to a buffer before the it returns Poll::Pending.