pub struct Error(/* private fields */);Expand description
Errors encountered by the timer implementation.
Currently, there are two different errors that can occur:
-
shutdownoccurs when a timer operation is attempted, but the timer instance has been dropped. In this case, the operation will never be able to complete and theshutdownerror is returned. This is a permanent error, i.e., once this error is observed, timer operations will never succeed in the future. -
at_capacityoccurs when a timer operation is attempted, but the timer instance is currently handling its maximum number of outstanding sleep instances. In this case, the operation is not able to be performed at the current moment, andat_capacityis returned. This is a transient error, i.e., at some point in the future, if the operation is attempted again, it might succeed. Callers that observe this error should attempt to shed load. One way to do this would be dropping the future that issued the timer operation.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn is_shutdown(&self) -> bool
pub fn is_shutdown(&self) -> bool
Returns true if the error was caused by the timer being shutdown.
Sourcepub fn at_capacity() -> Error
pub fn at_capacity() -> Error
Creates an error representing a timer at capacity.
Sourcepub fn is_at_capacity(&self) -> bool
pub fn is_at_capacity(&self) -> bool
Returns true if the error was caused by the timer being at capacity.
Sourcepub fn is_invalid(&self) -> bool
pub fn is_invalid(&self) -> bool
Returns true if the error was caused by the timer being misconfigured.